==> io-mokamint-node-1.3.1-sources.jar: io/mokamint/node/internal/TaskInfoImpl.java <==
/*
Copyright 2023 Fausto Spoto

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package io.mokamint.node.internal;

import java.util.Objects;

import io.hotmoka.annotations.Immutable;
import io.hotmoka.websockets.beans.api.InconsistentJsonException;
import io.mokamint.node.api.TaskInfo;
import io.mokamint.node.internal.gson.TaskInfoJson;

/**
 * An implementation of task information.
 */
@Immutable
public class TaskInfoImpl implements TaskInfo {

	/**
	 * The description of the task.
	 */
	private final String description;

	/**
	 * Creates a task information object.
	 * 
	 * @param description the description of the task
	 */
	public TaskInfoImpl(String description) {
		this.description = Objects.requireNonNull(description);
	}

	/**
	 * Creates a task info from the given JSON representation.
	 * 
	 * @param json the JSON representation
	 * @throws InconsistentJsonException if the JSON representation is inconsistent
	 */
	public TaskInfoImpl(TaskInfoJson json) throws InconsistentJsonException {
		String description = json.getDescription();
		if (description == null)
			throw new InconsistentJsonException("decription cannot be null");

		this.description = description;
	}

	@Override
	public String getDescription() {
		return description;
	}

	@Override
	public boolean equals(Object other) {
		return other instanceof TaskInfo info && description.equals(info.getDescription());
	}

	@Override
	public int hashCode() {
		return description.hashCode();
	}

	@Override
	public int compareTo(TaskInfo other) {
		return description.compareTo(other.getDescription());
	}

	@Override
	public String toString() {
		return getDescription();
	}
}

==> io-mokamint-node-1.6.0-sources.jar: io/mokamint/node/internal/TaskInfoImpl.java <==
/*
Copyright 2023 Fausto Spoto

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package io.mokamint.node.internal;

import java.util.Objects;

import io.hotmoka.annotations.Immutable;
import io.hotmoka.websockets.beans.api.InconsistentJsonException;
import io.mokamint.node.api.TaskInfo;
import io.mokamint.node.internal.json.TaskInfoJson;

/**
 * An implementation of task information.
 */
@Immutable
public class TaskInfoImpl implements TaskInfo {

	/**
	 * The description of the task.
	 */
	private final String description;

	/**
	 * Creates a task information object.
	 * 
	 * @param description the description of the task
	 */
	public TaskInfoImpl(String description) {
		this.description = Objects.requireNonNull(description);
	}

	/**
	 * Creates a task info from the given JSON representation.
	 * 
	 * @param json the JSON representation
	 * @throws InconsistentJsonException if the JSON representation is inconsistent
	 */
	public TaskInfoImpl(TaskInfoJson json) throws InconsistentJsonException {
		String description = json.getDescription();
		if (description == null)
			throw new InconsistentJsonException("decription cannot be null");

		this.description = description;
	}

	@Override
	public String getDescription() {
		return description;
	}

	@Override
	public boolean equals(Object other) {
		return other instanceof TaskInfo info && description.equals(info.getDescription());
	}

	@Override
	public int hashCode() {
		return description.hashCode();
	}

	@Override
	public int compareTo(TaskInfo other) {
		return description.compareTo(other.getDescription());
	}

	@Override
	public String toString() {
		return getDescription();
	}
}
